@@ -4,7 +4,7 @@ from pathlib import Path
 from pybi.core import DataSource
 import pandas as pd
 
-from typing import TYPE_CHECKING, Callable, Dict, List, Optional, Union, Any
+from typing import TYPE_CHECKING, Dict, List, Optional, Union
 import os
 
 from pybi.core.components import (
@@ -35,7 +35,9 @@ from pybi.utils.data_gen import (
 )
 from pybi.core.sql import Sql
 import pybi.utils.sql as sqlUtils
-from pybi.easyEcharts.base import BaseChart
+from pybi.easyEcharts.base import BaseChart, ChartCollector
+from pybi.easyEcharts import easy_echarts
+from pybi.core.components.reactiveComponent.echarts import EChartInfo
 
 if TYPE_CHECKING:
     pass
@@ -53,6 +55,18 @@ class AppMeta:
         self.__app.dbLocalStorage = on
         return self
 
+    def set_echarts_renderer(self, renderer="canvas"):
+        """
+        echarts renderer type: 'canvas' or 'svg'
+        'canvas' is default
+        """
+        self.__app.echartsRenderer = renderer
+        return self
+
+    def set_doc_title(self, title: str):
+        self.__app._doc_title = title
+        return self
+
 
 class App(ContainerComponent):
     def __init__(self) -> None:
@@ -63,6 +77,8 @@ class App(ContainerComponent):
         self._with_temp_host_stack: List[ContainerComponent] = []
         self._clear_data = False
         self.dbLocalStorage = False
+        self.echartsRenderer = "canvas"
+        self._doc_title = None
         self.__meta = AppMeta(self)
 
     def __record_and_check_dataset_name(self, name: str):
@@ -189,7 +205,11 @@ class App(ContainerComponent):
         host: Optional[ContainerComponent] = None,
     ):
 
-        sql = f"select {dataSourceTable.get_sql_fields()} from {dataSourceTable.source_name}"
+        sql = ""
+        if dataSourceTable._user_specified_field:
+            sql = dataSourceTable._to_sql()
+        else:
+            sql = f"select * from {dataSourceTable.source_name}"
         cp = Table(Sql(sql))
 
         host = host or self._get_temp_host() or self
@@ -199,23 +219,40 @@ class App(ContainerComponent):
 
     def add_echart(
         self,
-        options: Union[Dict, BaseChart],
+        options: Union[Dict, BaseChart, ChartCollector],
         *,
         host: Optional[ContainerComponent] = None,
     ):
         cp = None
 
-        if isinstance(options, BaseChart):
-            opts, infos = options.get_options_infos()
-            cp = EChart(opts)
+        if isinstance(options, (BaseChart, ChartCollector)):
+
+            if isinstance(options, BaseChart):
+                options = ChartCollector().append(options)
+
+            cp = EChart()
+
+            if (
+                len(options._collector) > 1
+                and easy_echarts._settings.drill_down_default_set_click_filter
+            ):
+                for chart in options._collector:
+                    chart._create_default_click_filter()
+
+            for chart in options._collector:
+                opts, ds_infos, updateInfos = chart.get_options_infos()
+
+                info = EChartInfo(opts, list(ds_infos), updateInfos)
+                cp._add_chart_info(info)
 
-            for info in infos:
-                cp.add_sql_path(info)
         else:
-            cp = EChart(options)
+            cp = EChart()
 
-            for info in EChart._extract_dataset_infos_from_option_(options):
-                cp.add_sql_path(info)
+            ds_infos = [
+                info for info in EChart._extract_dataset_infos_from_option_(options)
+            ]
+            info = EChartInfo(options, ds_infos, [])
+            cp._add_chart_info(info)
 
         host = host or self._get_temp_host() or self
         host._add_children(cp)
@@ -305,6 +342,8 @@ class App(ContainerComponent):
         data["dbFile"] = ds2sqlite_file_base64(
             self.dataSources, clear_data=self._clear_data
         )
+        if self._doc_title:
+            data["docTitle"] = self._doc_title
         return data
 
     def __reset_data(self):
