@@ -14,10 +14,15 @@ class Component(Jsonable):
     def __init__(self, tag: ComponentTag) -> None:
         self.id = get_global_id()
         self.tag = tag
+        self._debugTag: Optional[str] = None
         self._styles: List[Style] = []
         self.visible: Union[bool, Sql] = True
         self.__gridArea: str = ""
 
+    def set_debugTag(self, tag: str):
+        self._debugTag = tag
+        return self
+
     def set_gridArea(self, area_name: str):
         self.__gridArea = area_name
         return self
@@ -35,6 +40,8 @@ class Component(Jsonable):
         if self.__gridArea:
             data["gridArea"] = self.__gridArea
 
+        data["debugTag"] = self._debugTag
+
         return data
 
     def __add__(self, other: Style):
