@@ -163,12 +163,14 @@ class DataSourceTable(DataSourceView):
         source_name: str,
         columns: List[str],
         *,
+        user_specified_field=False,
         host: App,
     ) -> None:
         super().__init__()
         self.source_name = source_name
         self.columns = columns
         self.__host = host
+        self._user_specified_field = user_specified_field
 
     def __iter__(self):
         return self
@@ -179,7 +181,9 @@ class DataSourceTable(DataSourceView):
     def __getitem__(self, field: Union[str, List[str]]):
         if isinstance(field, str):
             return DataSourceField(self.source_name, field)
-        return DataSourceTable(self.source_name, field, host=self.__host)
+        return DataSourceTable(
+            self.source_name, field, user_specified_field=True, host=self.__host
+        )
 
     def to_pivot(
         self,
@@ -209,8 +213,8 @@ class DataSourceTable(DataSourceView):
         >>> *
         >>> a,b,c
         """
-        cols = (f"`{c}`" for c in self.columns)
-        return "*" if len(self.columns) == 0 else ",".join(cols)
+        # cols = (f"`{c}`" if c != "*" else c for c in self.columns)
+        return "*" if len(self.columns) == 0 else ",".join(self.columns)
 
     def _to_sql(self):
         fields = self.get_sql_fields()
