@@ -1,9 +1,11 @@
 from __future__ import annotations
 from .base import BaseChart
 import pybi as pbi
+import pybi.utils.sql as sqlUtils
 
 from typing import TYPE_CHECKING, Optional
 from pybi.core.components.reactiveComponent import EChartDatasetInfo
+from .utils import merge_user_options
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -16,7 +18,7 @@ class LineChart(BaseChart):
         x: str,
         y: str,
         color: Optional[str] = None,
-        agg="avg",
+        agg="round(avg(${}),2)",
     ):
         super().__init__()
         self.data = data
@@ -37,8 +39,12 @@ class LineChart(BaseChart):
         self._series_configs["areaStyle"] = {}
         return self
 
+    def _create_default_click_filter(self):
+        self.click_filter("x", self.data, self.x)
+
     def get_options_infos(self):
         opts = super().get_options()
+        update_config, update_axis, remove_series = merge_user_options(opts)
 
         opt_data = None
         if self.color:
@@ -46,11 +52,13 @@ class LineChart(BaseChart):
                 row=self.x, column=self.color, cell=self.y, agg=self.agg
             )
         else:
+            agg_field = sqlUtils.apply_agg(self.agg, self.y)
             opt_data = pbi.set_dataView(
-                f"select `{self.x}`,{self.agg}(`{self.y}`) from {self.data} group by `{self.x}`"
+                f"select `{self.x}`,{agg_field} from {self.data} group by `{self.x}`"
             )
 
         series_config = {"type": "line"}
+        update_config(series_config)
         series_config.update(self._series_configs)
 
         ds_info = EChartDatasetInfo(series_config, "dataset[0]", opt_data.source_name)
@@ -64,9 +72,13 @@ class LineChart(BaseChart):
 
         opts["yAxis"] = [{"type": "value"}]
 
+        update_axis(opts)
+
         opts["tooltip"] = {
             "trigger": "axis",
             "axisPointer": {"type": "cross", "label": {"backgroundColor": "#6a7985"}},
         }
 
-        return opts, [ds_info]
+        remove_series()
+
+        return opts, [ds_info], self._updateInfos
