@@ -4,6 +4,7 @@ import pybi as pbi
 
 from typing import TYPE_CHECKING, Optional
 from pybi.core.components.reactiveComponent import EChartDatasetInfo
+from .utils import merge_user_options
 
 if TYPE_CHECKING:
     from pybi.core.dataSource import DataSourceTable
@@ -16,18 +17,25 @@ class ScatterChart(BaseChart):
         x: str,
         y: str,
         color: Optional[str] = None,
-        agg="avg",
+        size: Optional[str] = None,
+        agg="round(avg(${}),2)",
     ):
         super().__init__()
         self.data = data
         self.x = x
         self.y = y
         self.color = color
+        self.size = size
         self.agg = agg
         self._series_configs = {}
 
+    def _create_default_click_filter(self):
+        # TODO:
+        self.click_filter("x", self.data, self.x)
+
     def get_options_infos(self):
         opts = super().get_options()
+        update_config, update_axis, remove_series = merge_user_options(opts)
 
         opt_data = None
         if self.color:
@@ -43,6 +51,8 @@ class ScatterChart(BaseChart):
             "type": "scatter",
         }
 
+        update_config(series_config)
+
         series_config.update(self._series_configs)
 
         ds_info = EChartDatasetInfo(series_config, "dataset[0]", opt_data.source_name)
@@ -51,6 +61,10 @@ class ScatterChart(BaseChart):
 
         opts["yAxis"] = [{}]
 
+        update_axis(opts)
+
         opts["tooltip"] = {"trigger": "item"}
 
-        return opts, [ds_info]
+        remove_series()
+
+        return opts, [ds_info], self._updateInfos
